﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Problems.DataAnalysis;

namespace HeuristicLab.DataPreprocessing {

  public interface IPreprocessingData : INamedItem {
    T GetCell<T>(string variableName, int row);
    void SetCell<T>(string variableName, int row, T value);
    string GetCellAsString(string variableName, int row);

    IList<T> GetValues<T>(string variableName);
    void SetValues<T>(string variableName, IEnumerable<T> values);

    void InsertRow(int rowIndex);
    void DeleteRow(int rowIndex);

    void InsertColumn<T>(string variableName, int columnIndex);
    void DeleteColumn(string variableName);

    IntRange TrainingPartition { get; }
    IntRange TestPartition { get; }

    IEnumerable<string> VariableNames { get; }
    string GetVariableName(int columnIndex);
    bool IsType<T>(string variableName);

    int Columns { get; }
    int Rows { get; }

    Dataset ExportToDataset();
  }
}
